from django.contrib.contenttypes.models import ContentType
from django.utils.translation import gettext as _
from dynamic_preferences.preferences import Section
from dynamic_preferences.registries import global_preferences_registry
from dynamic_preferences.types import ModelMultipleChoicePreference

mailing_section = Section("wbwiki")


@global_preferences_registry.register
class AllowedTypeWikiRelationshipPreference(ModelMultipleChoicePreference):
    section = mailing_section
    name = "allowed_type_wiki_relationship"
    queryset = ContentType.objects.all()
    default = []
    verbose_name = _("Allowed Type Wiki Relationship")



# Generated by Django 4.1.8 on 2023-04-19 05:27

from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("tags", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="WikiArticle",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("tag_detail_endpoint", models.CharField(blank=True, max_length=255, null=True)),
                ("tag_representation", models.CharField(blank=True, max_length=512, null=True)),
                ("title", models.CharField(max_length=1024)),
                ("content", models.TextField(default="")),
                ("summary", models.TextField(default="")),
                (
                    "tags",
                    models.ManyToManyField(blank=True, related_name="%(app_label)s_%(class)s_items", to="tags.tag"),
                ),
            ],
            options={
                "verbose_name": "Wiki Article",
                "verbose_name_plural": "Wiki Articles",
            },
        ),
    ]
